(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: termemu.mli 187 2005-10-14 10:54:15Z gerd $ *)

(* Terminal emulation for Linux consoles *)

type intensity = I_norm | I_dim | I_bold

type color = Black | Red | Green | Brown | Blue | Magenta | Cyan | White

val color : color -> string
  (* Returns color name *)

type atts =
    { intense : intensity;
      underscore : bool;
      blink : bool;
      reverse : bool;
      fg_color : color;
      bg_color : color
    }

type cell_char = Empty | Unicode of int
  (* The character stored in a screen cell *)

type key =
    [ `Translated of int
	(* An already translated Unicode key *)
    | `Cursor_up
    | `Cursor_down
    | `Cursor_left
    | `Cursor_right
    | `Page_up
    | `Page_down
    | `Home
    | `End
    | `Insert
    | `Delete
    | `Backspace
    | `Enter
    | `Tab
    | `Escape
    | `Fn of int
	(* Function key. int = 1..12 *)
    ]

class terminal_emulator : (* width: *) int -> (* height: *) int ->
object
  method height : int
    (* Returns the fixed height *)

  method width : int
    (* Returns the fixed width *)

  method screen : (cell_char * atts) array array
    (* The current contents of the screen. The outer array stores the rows, the
     * inner arrays the columns.
     *)

  method screen_as_html : string
    (* Returns the screen contents as HTML-formatted string *)

  method cursor_x : int
    (* Returns the X position of the cursor, from 0 .. width - 1 *)

  method cursor_y : int
    (* Returns the Y position of the cursor, from 0 .. height - 1 *)

  method cursor_visible : bool
    (* Whether the cursor is visible *)

  method output_char : char -> unit
    (* Outputs a single character to the terminal *)

  method add_input_string : string -> unit
    (* Adds a string to the input buffer of the terminal *)

  method add_input_key : key -> unit
    (* Adds a keystroke to the input buffer of the terminal *)

  method input_string : unit -> string
    (* Returns the input buffer (and clears it) *)

  method reset : unit -> unit
    (* Resets the terminal *)



end
